<?php

// +-----------------------------------------------------+
// | blog.php                                            |
// | ========                                            |
// |                                                     |
// | Add/edit/delete entries                             |
// | Started: 2005-05-21                                 |
// | Edited: 2005-06-27                                  |
// | (c) 2005 yabs                                       |
// +-----------------------------------------------------+
 
	if($_SESSION['right'][RIGHT_ENTRIES]){
		$query = array();
		
		$extend_script = '	<script type="text/javascript">
								function extend(id, image) {
									if (document.getElementById) {
										el = document.getElementById(id);
										if (el.style.display == \'none\') {
											document.getElementById(image).src = \''.site_true_home().'/templates/'.$config['template'].'/images//minus.png\';
											el.style.display = \'\';
										} else {
											document.getElementById(image).src = \''.site_true_home().'/templates/'.$config['template'].'/images/plus.png\';
											el.style.display = \'none\';
										}
									}
								}
							</script>';
		
		switch(@$_GET['action']){
			case 'list':
				$tpl->add_tpl('admin/blog_list.tpl');
				if(isset($_GET['offset']) && is_numeric($_GET['offset'])) $offset = $_GET['offset'];
				else $offset = 0;
				$list_sql = "	SELECT
									*
								FROM
									".$dbprefix."blog";
				if(!$_SESSION['right'][RIGHT_EDITALLENTRIES]){
					$list_sql .= " WHERE Autor = '".$_SESSION['UserID']."' ";
				}
				$list_sql .= "	ORDER BY
									date DESC
								LIMIT
									".$offset.", 30;";
				$list_res = $db->query($list_sql);
				$fillin = $tpl->parse_explodes(1);
				$finalecho = "";
				while($list = $db->fetch($list_res)){
					$echo = $tpl->fillin_explode('INPUT_ID', '<input type="radio" name="ID" value="'.$list['ID'].'" />', $fillin);
					$echo = $tpl->fillin_explode('ENTRY_TITLE', changetext($list['Titel']), $echo);
					$echo = $tpl->fillin_explode('ENTRY_DATE', strftime('%m-%d-%Y %H:%M', $list['date']), $echo);
					if(!$list['hidden']){
						$echo = $tpl->fillin_explode('ENTRY_ACTIVE', $lang['admin_entry_active'], $echo);
					}else{
						$echo = $tpl->fillin_explode('ENTRY_ACTIVE', $lang['admin_entry_inactive'], $echo);
					}
					$finalecho .= $echo;
				}
				$tpl->replace_array($finalecho, 1);
				$tpl->parse_implode();
				
				$tpl->fillin('FORM_TITLE', $lang['admin_form_title']);
				$tpl->fillin('FORM_DATE', $lang['admin_form_date']);
				$tpl->fillin('FORM_ACTIVE', $lang['admin_form_active']);
				$query['admin'] = 'blog';
				$tpl->fillin('OTHER_ACTION', '<a href="'.url_admin($query).'">'.$lang['admin_add_entry'].'</a>');
				$query['action'] = 'use';
				$tpl->fillin('ACTION', url_admin($query));
				$tpl->fillin('INPUT_EDIT', '<input type="submit" name="edit" value="'.$lang['admin_edit'].'" />');
				$tpl->fillin('INPUT_DELETE', '<input type="submit" name="delete" value="'.$lang['admin_delete'].'" />');
				
				$query['action'] = 'list';
				if($db->numrows($list_res) == 30){
						$query['offset'] = $offset + 30;
						$tpl->fillin('OLDER_ENTRIES', "<a href=\"".url_admin($query)."\">".$lang['older_entries']."</a>");
				}else{
					$tpl->fillin('OLDER_ENTRIES', '');
				}
				if($offset > 0){
					$offset_newer = $offset - 30;
					if($offset_newer < 0) $offset_newer = 0;
					$query['offset'] = $offset_newer;
					$tpl->fillin('NEWER_ENTRIES', "<a href=\"".url_admin($query)."\">".$lang['newer_entries']."</a>");
				}else{
					$tpl->fillin('NEWER_ENTRIES', '');
				}
				break;
			case 'use':
				if(isset($_POST['save'])){
					$tpl->add_tpl("admin/empty.tpl");
					$error = "";
					if(empty($_POST['title'])) $error .= $lang['admin_error_notitle'];
					if(empty($_POST['text'])) $error .= $lang['admin_error_notext'];
					if(!isset($_POST['extended'])) $_POST['extended'] = '';
					
					if(empty($error)){
						if(isset($_POST['nofeedback']) && $_POST['nofeedback'] == 'true') $nofeedback = 1;
						else $nofeedback = 0;
						if(isset($_POST['hide']) && $_POST['hide'] == 'true') $hidden = 1;
						else $hidden = 0;
						$save_sql = "	UPDATE
											".$dbprefix."blog
										SET
											Titel = '".slashes($_POST['title'])."',
											Inhalt = '".slashes($_POST['text'])."',
											extended = '".slashes($_POST['extended'])."',
											cat = '".$_POST['cat']."',
											date = '".mktime($_POST['hour'], $_POST['minute'], 0, $_POST['month'], $_POST['day'], $_POST['year'])."',
											nofeedback = '".$nofeedback."',
											hidden = '".$hidden."'
										WHERE
											ID = '".$_POST['ID']."';";
						$db->query($save_sql);
						$query['admin'] = 'blog';
						$tpl->fillin('CONTENT', $lang['admin_blog_saved'].'<a href="'.url_admin($query).'">'.$lang['continue'].'</a>');
					}else{
						$tpl->fillin('CONTENT', $error.$lang['back']);
					}
				}elseif(isset($_POST['edit'])){
					if(isset($_POST['ID'])){
						$edit_sql = "	SELECT
											*
										FROM
											".$dbprefix."blog
										WHERE
											ID = '".$_POST['ID']."'";
						if(!$_SESSION['right'][RIGHT_EDITALLENTRIES]){
							$edit_sql .= " and Autor = '".$_SESSION['UserID']."'";
						}
						$edit_res = $db->query($edit_sql . ';');
						if($db->numrows($edit_res) > 0){
							$edit = $db->fetch($edit_res);
							$tpl->add_tpl('admin/blog_form.tpl');
							$query['admin'] = 'blog';
							$tpl->fillin('OTHER_ACTION', '<a href="'.url_admin($query).'">'.$lang['admin_add_entry'].'</a>');
							$query['action'] = 'use';
							$tpl->fillin('ACTION', url_admin($query));
							$tpl->fillin('FORM_TITLE', $lang['admin_blog_form_title']);
							$tpl->fillin('INPUT_TITLE', '<input type="text" size="45" name="title" value="'.$edit['Titel'].'" maxlength="255" />');
							$tpl->fillin('FORM_CATEGORIE', $lang['admin_form_categorie']);
							$tpl->fillin('INPUT_HIDDEN', '<input type="hidden" name="ID" value="'.$_POST['ID'].'" />');
							$tpl->fillin('FORM_EXTENDED', $lang['admin_blog_form_extended']);
							if(!empty($edit['extended'])){
								$tpl->fillin('IMAGE_EXTEND', '<a href="#" onclick="extend(\'extended\', \'extendimg\'); return false"><img src="'.site_true_home().'/templates/'.$config['template'].'/images/minus.png" id="extendimg" alt="+/-" border="0" /></a>');
								$tpl->fillin('SCRIPT_HIDE_EXTENDED', '	<script type="text/javascript" l>
																			document.getElementById("options").style.display = "none";
																		</script>');
							}else{
								$tpl->fillin('SCRIPT_HIDE_EXTENDED', '	<script type="text/javascript">
																			document.getElementById("extended").style.display = "none";
																			document.getElementById("options").style.display = "none";
																		</script>');
								$tpl->fillin('IMAGE_EXTEND', '<a href="#" onclick="extend(\'extended\', \'extendimg\'); return false"><img src="'.site_true_home().'/templates/'.$config['template'].'/images/plus.png" id="extendimg" alt="+/-" border="0" /></a>');
							}
							$tpl->fillin('INPUT_EXTENDED', '<textarea name="extended" cols="50" rows="35">'.$edit['extended'].'</textarea>');
							$tpl->fillin('SCRIPT_EXTENDED', $extend_script);
							$tpl->fillin('BUTTON_BOLD', '<a href="#" onclick="insert_basic(document.forms[\'yabs_entry\'][\'text\'], \'b\'); return false"><img src="'.site_true_home().'/templates/'.$config['template'].'/images/button_bold.png" alt="" border="0" /></a>');
							$tpl->fillin('BUTTON_IMAGE', '<a href="#" onclick="insert_image(document.forms[\'yabs_entry\'][\'text\'], \''.$lang['form_image_location'].'\'); return false"><img src="'.site_true_home().'/templates/'.$config['template'].'/images/button_image.png" alt="" border="0" /></a>');
							$tpl->fillin('BUTTON_LINK', '<a href="#" onclick="insert_link(document.forms[\'yabs_entry\'][\'text\'], \''.$lang['form_link_location'].'\', \''.$lang['form_link_text'].'\'); return false"><img src="'.site_true_home().'/templates/'.$config['template'].'/images/button_link.png" alt="" border="0" /></a>');
							$tpl->fillin('BUTTON_QUOTE', '<a href="#" onclick="insert_basic(document.forms[\'yabs_entry\'][\'text\'], \'quote\'); return false"><img src="'.site_true_home().'/templates/'.$config['template'].'/images/button_quote.png" alt="" border="0" /></a>');
							$tpl->fillin('BUTTON_STROKE', '<a href="#" onclick="insert_basic(document.forms[\'yabs_entry\'][\'text\'], \'s\'); return false"><img src="'.site_true_home().'/templates/'.$config['template'].'/images/button_stroke.png" alt="" border="0" /></a>');
							$tpl->fillin('BUTTON_UNDERLINE', '<a href="#" onclick="insert_basic(document.forms[\'yabs_entry\'][\'text\'], \'u\'); return false"><img src="'.site_true_home().'/templates/'.$config['template'].'/images/button_underline.png" alt="" border="0" /></a>');
							$tpl->fillin('BUTTON_ITALIC', '<a href="#" onclick="insert_basic(document.forms[\'yabs_entry\'][\'text\'], \'i\'); return false"><img src="'.site_true_home().'/templates/'.$config['template'].'/images/button_italic.png" alt="" border="0" /></a>');
							$tpl->fillin('SCRIPT_EDITOR', '<script type="text/javascript" src="'.site_true_home().'/inc/editor.js"></script>');
							$tpl->fillin('BUTTON_BOLD_EXTENDED', '<a href="#" onclick="insert_basic(document.forms[\'yabs_entry\'][\'extended\'], \'b\'); return false"><img src="'.site_true_home().'/templates/'.$config['template'].'/images/button_bold.png" alt="" border="0" /></a>');
							$tpl->fillin('BUTTON_IMAGE_EXTENDED', '<a href="#" onclick="insert_image(document.forms[\'yabs_entry\'][\'extended\'], \''.$lang['form_image_location'].'\'); return false"><img src="'.site_true_home().'/templates/'.$config['template'].'/images/button_image.png" alt="" border="0" /></a>');
							$tpl->fillin('BUTTON_LINK_EXTENDED', '<a href="#" onclick="insert_link(document.forms[\'yabs_entry\'][\'extended\'], \''.$lang['form_link_location'].'\', \''.$lang['form_link_text'].'\'); return false"><img src="'.site_true_home().'/templates/'.$config['template'].'/images/button_link.png" alt="" border="0" /></a>');
							$tpl->fillin('BUTTON_QUOTE_EXTENDED', '<a href="#" onclick="insert_basic(document.forms[\'yabs_entry\'][\'extended\'], \'quote\'); return false"><img src="'.site_true_home().'/templates/'.$config['template'].'/images/button_quote.png" alt="" border="0" /></a>');
							$tpl->fillin('BUTTON_STROKE_EXTENDED', '<a href="#" onclick="insert_basic(document.forms[\'yabs_entry\'][\'extended\'], \'s\'); return false"><img src="'.site_true_home().'/templates/'.$config['template'].'/images/button_stroke.png" alt="" border="0" /></a>');
							$tpl->fillin('BUTTON_UNDERLINE_EXTENDED', '<a href="#" onclick="insert_basic(document.forms[\'yabs_entry\'][\'extended\'], \'u\'); return false"><img src="'.site_true_home().'/templates/'.$config['template'].'/images/button_underline.png" alt="" border="0" /></a>');
							$tpl->fillin('BUTTON_ITALIC_EXTENDED', '<a href="#" onclick="insert_basic(document.forms[\'yabs_entry\'][\'extended\'], \'i\'); return false"><img src="'.site_true_home().'/templates/'.$config['template'].'/images/button_italic.png" alt="" border="0" /></a>');
							$tpl->fillin('ID_EXTENDED', 'extended');
							$tpl->fillin('FORM_OPTIONS', $lang['admin_form_options']);
							$tpl->fillin('ID_OPTIONS', 'options');
							$tpl->fillin('IMAGE_OPTIONS', '<a href="#" onclick="extend(\'options\', \'optionimg\'); return false"><img src="'.site_true_home().'/templates/'.$config['template'].'/images/plus.png" id="optionimg" alt="+/-" border="0" /></a>');
							$tpl->fillin('FORM_NOFEEDBACK', $lang['admin_form_nofeedback']);
							if($edit['nofeedback']) $nofeedback = 'checked="checked "';
							else $nofeedback = '';
							$tpl->fillin('INPUT_NOFEEDBACK', '<input type="checkbox" name="nofeedback" value="true" '.$nofeedback.'/>');
							if($edit['hidden']) $hidden = 'checked="checked "';
							else $hidden = '';
							if($_SESSION['right'][RIGHT_ENTRYACTIVATION]){
								$tpl->fillin('INPUT_HIDE', '<input type="checkbox" name="hide" value="true" '.$hidden.'/>');
								$tpl->fillin('FORM_HIDE', $lang['admin_hide_entry']);
							}else{
								$tpl->fillin('FORM_HIDE', '');
								$tpl->fillin('INPUT_HIDE', '<input type="hidden" name="hide" value="true" />');
							}
									
							$months = "<select name=\"month\">\n";
							for($i=1;$i<=12;$i++){
								$months .= "<option value=\"".$i."\"";
								if(date('n', $edit['date']) == $i) $months .= " selected=\"selected\"";
								$months .= ">".strftime('%B', mktime(1, 1, 1, $i, 1, 1))."</option>\n";
							}
							$months .= "</select>\n";
							$tpl->fillin('INPUT_MONTH', $months);
							$hours = "<select name=\"hour\">\n";
							for($i=0;$i<=23;$i++){
								$hours .= "<option value=\"".$i."\"";
								if(date('H', $edit['date']) == $i) $hours .= " selected=\"selected\"";
								$hours .= ">".$i."</option>\n";
							}
							$hours .= "</select>";
							$tpl->fillin('INPUT_HOUR', $hours);
							$min = "<select name=\"minute\">\n";
							for($i=0;$i<=59;$i++){
								$min .= "<option value=\"".$i."\"";
								if(date('i', $edit['date']) == $i) $min .= " selected=\"selected\"";
								$min .= ">".$i."</option>\n";
							}
							$min .= "</select>";
							$tpl->fillin('INPUT_MINUTE', $min);
							$days = "<select name=\"day\">\n";
							for($i=1;$i<32;$i++){
								$days .= "<option value=\"".$i."\"";
								if(date('d',  $edit['date']) == $i) $days .= " selected=\"selected\"";
								$days .= ">".$i."</option>\n";
							}
							$days .= "</select>";
							$tpl->fillin('INPUT_DAY', $days);
							$years = "<select name=\"year\">\n";
							for($i = date('Y', time()) - 10; $i <= date('Y', time()) + 10; $i++){
								$years .= "<option value=\"".$i."\"";
								if(date('Y', $edit['date']) == $i) $years .= " selected=\"selected\"";
								$years .= ">".$i."</option>\n";
							}
							$years .= "</select>";
							$tpl->fillin('INPUT_YEAR', $years);
							$tpl->fillin('FORM_DATE', $lang['admin_form_date']);
							$categories = "<select name=\"cat\">\n<option value=\"0\">".$lang['admin_blog_nocat']."</option>\n";
							$cat_sql = "SELECT
											*
										FROM
											".$dbprefix."cat;";
							$cat_res = $db->query($cat_sql);
							while($cat = $db->fetch($cat_res)){
								$categories .= "<option value=\"".$cat['ID']."\"";
								if($cat['ID'] == $edit['cat']) $categories .= ' selected="selected"';
								$categories .= ">".$cat['Name']."</option>\n";
							}
							$tpl->fillin('INPUT_CATEGORIE', $categories.'</select>');
							$tpl->fillin('FORM_ENTRY', $lang['admin_form_entry']);
							$tpl->fillin('INPUT_ENTRY', '<textarea name="text" cols="55" rows="25">'.$edit['Inhalt'].'</textarea>');
							$tpl->fillin('INPUT_SUBMIT', '<input type="submit" name="save" value="'.$lang['admin_save'].'" />');
						}else{
							$tpl->add_tpl('admin/empty.tpl');
							$tpl->fillin('CONTENT', $lang['admin_error_entrydontexist'].$lang['back']);
						}
					}else{
						$tpl->add_tpl('admin/empty.tpl');
						$tpl->fillin('CONTENT', $lang['admin_error_noid'].$lang['back']);
					}
					
				}elseif(isset($_POST['delete'])){
					$tpl->add_tpl('admin/empty.tpl');
					if(isset($_POST['checked'])){
						$del_sql = "DELETE FROM
										".$dbprefix."blog
									WHERE
										ID = '".$_POST['ID']."'";
						if(!$_SESSION['right'][RIGHT_EDITALLENTRIES]){
							$del_sql .= " and Autor = '".$_SESSION['UserID']."'";
						}
						$db->query($del_sql . ';');
						$del_sql = "DELETE FROM
										".$dbprefix."comments
									WHERE
										BlogID = '".$_POST['ID']."';";
						$db->query($del_sql);
						$del_sql = "DELETE FROM
										".$dbprefix."trackback
									WHERE
										BlogID = '".$_POST['ID']."';";
						$db->query($del_sql);
						$yabs->deletecachedentry($_POST['ID']);
						$query['admin'] = 'blog';
						$tpl->fillin('CONTENT', $lang['admin_blog_deleted']."<a href=\"".url_admin($query)."\">".$lang['admin_continue']."</a>");
					}else{
						if(isset($_POST['ID'])){
							$query['admin'] = 'blog';
							$query['action'] = 'use';
							$fillin = "<form action=\"".url_admin($query)."\" method=\"post\">\n";
							$fillin .= "<input type=\"hidden\" name=\"checked\" value=\"true\" />\n";
							$fillin .= "<input type=\"hidden\" name=\"ID\" value=\"".$_POST['ID']."\" />";
							$fillin .= $lang['admin_blog_delete_recheck'];
							$fillin .= '<input type="submit" name="delete" value="'.$lang['admin_delete'].'" />';
							$fillin .= "\n</form>\n";
							$tpl->fillin('CONTENT', $fillin);
						}else{
							$tpl->fillin('CONTENT', $lang['admin_error_noid'].$lang['back']);
						}
					}
				}else{
					$query = array();
					$query['admin'] = 'blog';
					header('location: '.url_admin($query));
					exit();
				}
				break;
			case 'add':
				if(isset($_POST['save'])){
					$tpl->add_tpl("admin/empty.tpl");
					$error = "";
					if(empty($_POST['title'])) $error .= $lang['admin_error_notitle'];
					if(empty($_POST['text'])) $error .= $lang['admin_error_notext'];
					if(!isset($_POST['extended'])) $_POST['extended'] = '';
					if(isset($_POST['nofeedback']) && $_POST['nofeedback'] == 'true') $nofeedback = 1;
					else $nofeedback = 0;
					if(isset($_POST['hide']) && $_POST['hide'] == 'true') $hidden = 1;
					else $hidden = 0;
					
					if(empty($error)){
						$blog_sql = "	INSERT INTO ".$dbprefix."blog
											(Autor,
											 date,
											 Titel,
											 Inhalt,
											 extended,
											 cat,
											 nofeedback,
											 hidden
											)
										VALUES
											('".$_SESSION['UserID']."',
											 '".mktime($_POST['hour'], $_POST['minute'], 0, $_POST['month'], $_POST['day'], $_POST['year'])."',
											 '".slashes($_POST['title'])."',
											 '".slashes($_POST['text'])."',
											 '".slashes($_POST['extended'])."',
											 '".$_POST['cat']."',
											 '".$nofeedback."',
											 '".$hidden."'
											);";
						$db->query($blog_sql);
						$echo = $lang['admin_blog_saved'];
						//Begin of Trackback Code
						$text = $_POST['text'];
						//Filter all URLs out of the text
						$uri_array = array();
						if(preg_match_all('#http://(.*)[\s|\[|\]]#Uis', ' '.$_POST['text'].' '.$_POST['extended']." ", $match)){
							$match[1] = array_unique($match[1]);
							//URL von diesem Eintrag erzeugen, um sie bei TB zu senden
							$url_sql = "SELECT
											ID
										FROM
											".$dbprefix."blog
										ORDER BY
											ID DESC
										LIMIT
											0, 1;";
							$url_res = $db->query($url_sql);
							$blog_url = $db->fetch($url_res);
							//$url = "http://".$_SERVER['HTTP_HOST'].dirname($_SERVER['PHP_SELF'])."?site=blog&amp;id=".$blog_url['ID'];
							// +-----------------------------------------------------+
							// | Trackback-Code                                      |
							// +-----------------------------------------------------+
							if($config['send_tb']){
								$echo .= "\n<ul>\n";
								// Fr jede URL eine TB-Anfrage senden
								foreach($match[1] as $link){
									$link = "http://".trim($link);
									$echo .= "<li>".trim($link)."<br />";
									$tb = new Trackback($link);
									// Wenn fsockopen erfolgreich war, dann weiter
									if($tb->getTBstatus()){
										if($tb->searchTBident($link)){
											if($tb->matchTBident($link)){
												if($tb->getTBping() != false){
													$url = array();
													$url['entry'] = $blog_url['ID'];
													if(($tbres = $tb->sendTB($config['Title'], url($url, 0, 'index.php', $_POST['title']), blank_text($_POST['title'], 255, 0), nl2br(blank_text($_POST['text'], 200, 0)."..."))) == '0'){
														$echo .= $lang['admin_tb_success'];
													}else{
														$echo .= $lang['admin_error_tb_failed'];
														if($tbres === -1){
															$echo .= $lang['admin_tb_error_noreturn'];
														}else{
															$echo .= trim($tbres);
														}
													}
												}else{
													$echo .= $lang['admin_error_tb_failed']." ".$lang['admin_error_tb_noping'];
												}
											}else{
												$echo .= $lang['admin_error_tb_failed']." ".$lang['admin_error_tb_ident'];
											}
										}else{
											$echo .= $lang['admin_error_tb_failed']." ".$lang['admin_error_tb_notb'];
										}
									}else{
										$echo .= $lang['admin_error_tb_failed']." ".$lang['admin_error_tb_open'];
									}
									$echo .= "</li>\n";
								}
								$echo .= "</ul>\n";
							}
							$echo .= '<br />';
							// +-----------------------------------------------------+
							// | Pingback-Code (not done yet)                        |
							// +-----------------------------------------------------+
							/*
							if($config['send_ping']){
								$echo .= "\n<ul>\n";
								foreach($match[1] as $link){
									$link = "http://".trim($link);
									$echo .= "<li>".trim($link)."<br />";
									$ping = new Pingback($link);
									// +-----------------------------------------------------+
									// | Knnen wir die URI ffnen?                          |
									// +-----------------------------------------------------+
									if($ping->GetPingStatus()){
										// +-----------------------------------------------------+
										// | Pingback-Server suhern                              |
										// +-----------------------------------------------------+
										if($ping->SearchPing()){
											// +-----------------------------------------------------+
											// | sourceURI                                           |
											// +-----------------------------------------------------+
											$url = array();
											$url['id'] = $blog_url['ID'];
											// +-----------------------------------------------------+
											// | senden                                              |
											// +-----------------------------------------------------+
											if($ping->SendPing(url($url), $link) == 1){
												$echo .= $lang['admin_ping_success'];
											}else{
												$echo .= $lang['admin_error_ping_failed']." Fehlgeschalgen";
											}
										}else{
											$echo .= $lang['admin_error_ping_failed']." ".$lang['admin_error_ping_noping'];
										}
									}else{
										$echo .= $lang['admin_error_ping_failed']." ".$lang['admin_error_ping_open'];
									}
								}
								$echo .= "</ul>\n";
							}
							* */
						}
						$query['admin'] = 'blog';
						$echo .= "<br /><a href=\"".url_admin($query)."\">".$lang['admin_continue']."</a>";
						$tpl->fillin('CONTENT', $echo);
					}else{
						$tpl->fillin('CONTENT', $error.$lang['back']);
					}
				}else{
					$query = array();
					$query['admin'] = 'blog';
					header('location: '.url_admin($query));
					exit();
				}
				break;
			default:
				/*
				if(isset($_POST['preview'])){
					$tpl->add_tpl($config['template'.'/blog.tpl']);
					$tpl->fillin('EXPLODE', '');
					$autor_sql = "	SELECT
										name,
										email
									FROM
										".$mysql_prefix."user
									WHERE
										ID = '".$_SESSION['UserID']."';";
					$autor_res = new Query($autor_sql);
					$autor = $autor_res->fetch();
			
					$tpl->fillin("AUTOR", $autor['name']);
					$tpl->fillin("EMAIL", $autor['email']);
					
					$cat_sql = "SELECT
									Name
								FROM
									".$mysql_prefix."cat
								WHERE
									ID = '".$_POST['cat']."' and
									config = '"."';";
					$cat_res = new Query($cat_sql);
					if($cat_res->numrows()){
						$cat = $cat_res->fetch();
						$cat_url = array();
						$cat_url['cat'] = $_POST['cat'];
						$tpl->fillin('CATEGORIE', '<a href="'.url($cat_url).'">'.$cat['Name'].'</a>');
					}else{
						$tpl->fillin('CATEGORIE', '<a href="'.url(array()).'">'.$lang['admin_blog_nocat'].'</a>');
					}
					
					$tpl->fillin("TITEL", changetext(stripslashes(slashes($_POST['titel']))));
					$tpl->fillin("DATE", strftime($config['time_format'], mktime($_POST['hour'], $_POST['minute'], 0, $_POST['month'], $_POST['day'], $_POST['year'])));
					
					$tpl->fillin("INHALT", changetext(stripslashes(slashes($_POST['text']))).'<br />'.changetext(stripslashes(slashes($_POST['extended']))));
					$tpl->fillin("COMMENTS", str_replace("{N}", '0', $lang['comments']));
					$tpl->fillin("TRACKBACKS", str_replace("{N}", '0', $lang['trackbacks']));
				}
				*/
				$tpl->add_tpl('admin/blog_form.tpl');
				$query['admin'] = 'blog';
				$query['action'] = 'add';
				$tpl->fillin('ACTION', url_admin($query));
				
				$query['action'] = 'list';
				$tpl->fillin('OTHER_ACTION', '<a href="'.url_admin($query).'">'.$lang['admin_blog_edit_entries'].'</a>');
				$tpl->fillin('FORM_TITLE', $lang['admin_blog_form_title']);
				$tpl->fillin('INPUT_TITLE', '<input type="text" name="title" size="45" maxlength="255" />');
				$tpl->fillin('FORM_CATEGORIE', $lang['admin_form_categorie']);
				$tpl->fillin('FORM_EXTENDED', $lang['admin_blog_form_extended']);
				$tpl->fillin('INPUT_EXTENDED', '<textarea name="extended" cols="50" rows="35"></textarea>');
				$tpl->fillin('SCRIPT_EXTENDED', $extend_script);
				$tpl->fillin('ID_EXTENDED', 'extended');
				$tpl->fillin('SCRIPT_HIDE_EXTENDED', '	<script type="text/javascript">
															document.getElementById("extended").style.display = "none";
															document.getElementById("options").style.display = "none";
														</script>');
				$tpl->fillin('IMAGE_EXTEND', '<a href="#" onclick="extend(\'extended\', \'extendimg\'); return false"><img src="'.site_true_home().'/templates/'.$config['template'].'/images/plus.png" id="extendimg" alt="+/-" border="0" /></a>');
				$tpl->fillin('BUTTON_BOLD', '<a href="#" onclick="insert_basic(document.forms[\'yabs_entry\'][\'text\'], \'b\'); return false"><img src="'.site_true_home().'/templates/'.$config['template'].'/images/button_bold.png" alt="" border="0" /></a>');
				$tpl->fillin('BUTTON_IMAGE', '<a href="#" onclick="insert_image(document.forms[\'yabs_entry\'][\'text\'], \''.$lang['form_image_location'].'\'); return false"><img src="'.site_true_home().'/templates/'.$config['template'].'/images/button_image.png" alt="" border="0" /></a>');
				$tpl->fillin('BUTTON_LINK', '<a href="#" onclick="insert_link(document.forms[\'yabs_entry\'][\'text\'], \''.$lang['form_link_location'].'\', \''.$lang['form_link_text'].'\'); return false"><img src="'.site_true_home().'/templates/'.$config['template'].'/images/button_link.png" alt="" border="0" /></a>');
				$tpl->fillin('BUTTON_QUOTE', '<a href="#" onclick="insert_basic(document.forms[\'yabs_entry\'][\'text\'], \'quote\'); return false"><img src="'.site_true_home().'/templates/'.$config['template'].'/images/button_quote.png" alt="" border="0" /></a>');
				$tpl->fillin('BUTTON_STROKE', '<a href="#" onclick="insert_basic(document.forms[\'yabs_entry\'][\'text\'], \'s\'); return false"><img src="'.site_true_home().'/templates/'.$config['template'].'/images/button_stroke.png" alt="" border="0" /></a>');
				$tpl->fillin('BUTTON_UNDERLINE', '<a href="#" onclick="insert_basic(document.forms[\'yabs_entry\'][\'text\'], \'u\'); return false"><img src="'.site_true_home().'/templates/'.$config['template'].'/images/button_underline.png" alt="" border="0" /></a>');
				$tpl->fillin('BUTTON_ITALIC', '<a href="#" onclick="insert_basic(document.forms[\'yabs_entry\'][\'text\'], \'i\'); return false"><img src="'.site_true_home().'/templates/'.$config['template'].'/images/button_italic.png" alt="" border="0" /></a>');
				$tpl->fillin('SCRIPT_EDITOR', '<script type="text/javascript" src="'.site_true_home().'/inc/editor.js"></script>');
				$tpl->fillin('BUTTON_BOLD_EXTENDED', '<a href="#" onclick="insert_basic(document.forms[\'yabs_entry\'][\'extended\'], \'b\'); return false"><img src="'.site_true_home().'/templates/'.$config['template'].'/images/button_bold.png" alt="" border="0" /></a>');
				$tpl->fillin('BUTTON_IMAGE_EXTENDED', '<a href="#" onclick="insert_image(document.forms[\'yabs_entry\'][\'extended\'], \''.$lang['form_image_location'].'\'); return false"><img src="'.site_true_home().'/templates/'.$config['template'].'/images/button_image.png" alt="" border="0" /></a>');
				$tpl->fillin('BUTTON_LINK_EXTENDED', '<a href="#" onclick="insert_link(document.forms[\'yabs_entry\'][\'extended\'], \''.$lang['form_link_location'].'\', \''.$lang['form_link_text'].'\'); return false"><img src="'.site_true_home().'/templates/'.$config['template'].'/images/button_link.png" alt="" border="0" /></a>');
				$tpl->fillin('BUTTON_QUOTE_EXTENDED', '<a href="#" onclick="insert_basic(document.forms[\'yabs_entry\'][\'extended\'], \'quote\'); return false"><img src="'.site_true_home().'/templates/'.$config['template'].'/images/button_quote.png" alt="" border="0" /></a>');
				$tpl->fillin('BUTTON_STROKE_EXTENDED', '<a href="#" onclick="insert_basic(document.forms[\'yabs_entry\'][\'extended\'], \'s\'); return false"><img src="'.site_true_home().'/templates/'.$config['template'].'/images/button_stroke.png" alt="" border="0" /></a>');
				$tpl->fillin('BUTTON_UNDERLINE_EXTENDED', '<a href="#" onclick="insert_basic(document.forms[\'yabs_entry\'][\'extended\'], \'u\'); return false"><img src="'.site_true_home().'/templates/'.$config['template'].'/images/button_underline.png" alt="" border="0" /></a>');
				$tpl->fillin('BUTTON_ITALIC_EXTENDED', '<a href="#" onclick="insert_basic(document.forms[\'yabs_entry\'][\'extended\'], \'i\'); return false"><img src="'.site_true_home().'/templates/'.$config['template'].'/images/button_italic.png" alt="" border="0" /></a>');
				$tpl->fillin('FORM_OPTIONS', $lang['admin_form_options']);
				$tpl->fillin('ID_OPTIONS', 'options');
				$tpl->fillin('IMAGE_OPTIONS', '<a href="#" onclick="extend(\'options\', \'optionimg\'); return false"><img src="'.site_true_home().'/templates/'.$config['template'].'/images/plus.png" id="optionimg" alt="+/-" border="0" /></a>');
				$tpl->fillin('FORM_NOFEEDBACK', $lang['admin_form_nofeedback']);
				$tpl->fillin('INPUT_NOFEEDBACK', '<input type="checkbox" name="nofeedback" value="true" />');
				if($_SESSION['right'][RIGHT_ENTRYACTIVATION]){
					$tpl->fillin('INPUT_HIDE', '<input type="checkbox" name="hide" value="true" />');
					$tpl->fillin('FORM_HIDE', $lang['admin_hide_entry']);
				}else{
					$tpl->fillin('FORM_HIDE', '');
					$tpl->fillin('INPUT_HIDE', '<input type="hidden" name="hide" value="true" />');
				}
					
				$categories = "<select name=\"cat\">\n<option value=\"0\">".$lang['admin_blog_nocat']."</option>\n";
				$cat_sql = "SELECT
								*
							FROM
								".$dbprefix."cat;";
				$cat_res = $db->query($cat_sql);
				while($cat = $db->fetch($cat_res)){
					$categories .= "<option value=\"".$cat['ID']."\">".$cat['Name']."</option>\n";
				}
				$tpl->fillin('INPUT_CATEGORIE', $categories.'</select>');
				$tpl->fillin('FORM_ENTRY', $lang['admin_form_entry']);
				$tpl->fillin('INPUT_ENTRY', '<textarea name="text" cols="50" rows="25"></textarea>');
				$tpl->fillin('INPUT_SUBMIT', '<input type="submit" name="save" value="'.$lang['admin_save'].'" />');
				$tpl->fillin('INPUT_HIDDEN', '');
				$months = "<select name=\"month\">\n";
				for($i=1;$i<=12;$i++){
					$months .= "<option value=\"".$i."\"";
					if(date('n', time()) == $i) $months .= " selected=\"selected\"";
					$months .= ">".strftime('%B', mktime(1, 1, 1, $i, 1, 1))."</option>\n";
				}
				$months .= "</select>\n";
				$tpl->fillin('INPUT_MONTH', $months);
				$hours = "<select name=\"hour\">\n";
				for($i=0;$i<=23;$i++){
					$hours .= "<option value=\"".$i."\"";
					if(date('H', time()) == $i) $hours .= " selected=\"selected\"";
					$hours .= ">".$i."</option>\n";
				}
				$hours .= "</select>";
				$tpl->fillin('INPUT_HOUR', $hours);
				$min = "<select name=\"minute\">\n";
				for($i=0;$i<=59;$i++){
					$min .= "<option value=\"".$i."\"";
					if(date('i', time()) == $i) $min .= " selected=\"selected\"";
					$min .= ">".$i."</option>\n";
				}
				$min .= "</select>";
				$tpl->fillin('INPUT_MINUTE', $min);
				$days = "<select name=\"day\">\n";
				for($i=1;$i<32;$i++){
					$days .= "<option value=\"".$i."\"";
					if(date('d', time()) == $i) $days .= " selected=\"selected\"";
					$days .= ">".$i."</option>\n";
				}
				$days .= "</select>";
				$tpl->fillin('INPUT_DAY', $days);
				$years = "<select name=\"year\">\n";
				for($i = date('Y', time()) - 10; $i <= date('Y', time()) + 10; $i++){
					$years .= "<option value=\"".$i."\"";
					if(date('Y', time()) == $i) $years .= " selected=\"selected\"";
					$years .= ">".$i."</option>\n";
				}
				$years .= "</select>";
				$tpl->fillin('INPUT_YEAR', $years);
				$tpl->fillin('FORM_DATE', $lang['admin_form_date']);
				break;
		}
	}else{
		$tpl->add_tpl('admin/empty.tpl');
		$tpl->fillin('CONTENT', $lang['admin_error_access_denied'].$lang['back']);
	}
	
?>